@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package asn1
@@ -46,13 +41,13 @@ func TestEncoder_GetData(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Encoder{
 				data: tt.fields.data,
 			}
-
 			got := c.GetData()
 			if diff := cmp.Diff(tt.want, got); diff != "" {
 				t.Fatalf("Encoder.GetData() = %s", diff)
@@ -71,7 +66,6 @@ func TestEncoder_WriteRequest(t *testing.T) {
 	type args struct {
 		path []int
 		tag  string
-		cmd  int
 	}
 
 	tests := []struct {
@@ -86,7 +80,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, NodeType, EmberGetDirCommand},
+			args{[]int{}, NodeType},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x6a, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -99,7 +93,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, QualifiedNodeType, EmberGetDirCommand},
+			args{[]int{}, QualifiedNodeType},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x6a, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -112,7 +106,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, ParameterType, EmberGetDirCommand},
+			args{[]int{}, ParameterType},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x69, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -125,7 +119,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, QualifiedParameterType, EmberGetDirCommand},
+			args{[]int{}, QualifiedParameterType},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x69, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -138,7 +132,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, FunctionType, EmberGetDirCommand},
+			args{[]int{}, FunctionType},
 			[]byte{
 				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x74, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00,
@@ -151,7 +145,7 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			fields{
 				bytes.NewBuffer([]byte{0x00}),
 			},
-			args{[]int{}, FunctionType, EmberGetDirCommand},
+			args{[]int{}, FunctionType},
 			[]byte{
 				0x00, 0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x74, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
 				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x20, 0xa1, 0x03, 0x02, 0x01, 0xff, 0x00, 0x00, 0x00,
@@ -159,38 +153,26 @@ func TestEncoder_WriteRequest(t *testing.T) {
 			},
 			false,
 		},
-		{
-			"+unsubscribe",
-			fields{
-				bytes.NewBuffer([]byte{}),
-			},
-			args{[]int{}, ParameterType, EmberGetUnsubscribeCommand},
-			[]byte{
-				0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x69, 0x80, 0xa0, 0x80, 0x0d, 0x00, 0xa2, 0x80, 0x64, 0x80,
-				0xa0, 0x80, 0x62, 0x80, 0xa0, 0x03, 0x02, 0x01, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-				0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-			},
-			false,
-		},
 		{
 			"-invalidType",
 			fields{
 				bytes.NewBuffer([]byte{}),
 			},
-			args{[]int{}, "foobar", EmberGetDirCommand},
+			args{[]int{}, "foobar"},
 			[]byte{0x60, 0x80, 0x6b, 0x80, 0xa0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
 			true,
 		},
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Encoder{
 				data: tt.fields.data,
 			}
-			if err := c.WriteRequest(tt.args.path, tt.args.tag, tt.args.cmd); (err != nil) != tt.wantErr {
+			if err := c.WriteRequest(tt.args.path, tt.args.tag); (err != nil) != tt.wantErr {
 				t.Fatalf("Encoder.WriteRequest() error = %v, wantErr %v", err, tt.wantErr)
 			}
 
@@ -251,6 +233,7 @@ func TestEncoder_WriteUniversal(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -300,6 +283,7 @@ func TestEncoder_WriteRootTreeRequest(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -324,21 +308,15 @@ func TestEncoder_WriteGetDirCommand(t *testing.T) {
 		data *bytes.Buffer
 	}
 
-	type args struct {
-		cmd int
-	}
-
 	tests := []struct {
 		name    string
 		fields  fields
-		args    args
 		want    []byte
 		wantErr bool
 	}{
 		{
 			"+valid",
 			fields{bytes.NewBuffer([]byte{})},
-			args{EmberGetDirCommand},
 			[]byte{
 				0xa0, 0x80, 0x62, 0x80, 0xA0, 0x03, 0x02, 0x01, 0x20, 0xA1, 0x03, 0x02, 0x01,
 				0xFF, 0x00, 0x00, 0x00, 0x00,
@@ -348,7 +326,6 @@ func TestEncoder_WriteGetDirCommand(t *testing.T) {
 		{
 			"+existingData",
 			fields{bytes.NewBuffer([]byte{0x00, 0x00})},
-			args{EmberGetDirCommand},
 			[]byte{
 				0x00, 0x00, 0xa0, 0x80, 0x62, 0x80, 0xA0, 0x03, 0x02, 0x01, 0x20, 0xA1, 0x03, 0x02, 0x01,
 				0xFF, 0x00, 0x00, 0x00, 0x00,
@@ -358,13 +335,14 @@ func TestEncoder_WriteGetDirCommand(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Encoder{
 				data: tt.fields.data,
 			}
-			if err := c.WriteCommand(tt.args.cmd); (err != nil) != tt.wantErr {
+			if err := c.WriteGetDirCommand(); (err != nil) != tt.wantErr {
 				t.Fatalf("Encoder.WriteGetDirCommand() error = %v, wantErr %v", err, tt.wantErr)
 			}
 
@@ -417,6 +395,7 @@ func TestEncoder_writeInt(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -466,6 +445,7 @@ func TestEncoder_openSequence(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -506,6 +486,7 @@ func TestEncoder_closeSequence(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
