@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package s101
@@ -22,13 +17,9 @@ package s101
 const (
 	// FirstMultiPacket is byte to identify a multilayer packet in S101.
 	FirstMultiPacket = 0x80
-	// BodyMultiPacket is byte to identify a packet in a multilayer packet message in S101.
-	BodyMultiPacket = 0x00
-	// LastMultiPacket is byte to identify end of a multilayer packet in S101.
-	LastMultiPacket = 0x40
-	// SinglePacket is byte to identify a single packet message in S101.
-	SinglePacket = 0xC0
 
+	// LastMultiPacket is byte to identify end of a multilayer packet in S101.
+	lastMultiPacket = 0x40
 	// BOF S101 packet opening byte.
 	bof = 0xfe
 	// Slot S101 packet Slot byte.
@@ -60,10 +51,10 @@ const (
 
 	// s101LenTilGlow is offset for how many S101 bytes it takes to get till Glow payload.
 	s101LenTilGlow = 10
-	// s101LenAfterGlow is offset for how many S101 bytes follow Glow payload till EOF.
-	s101LenAfterGlow = 3
 	// checkSumSecondDeviation is byte used in CRC calculations based on ember+ documentation.
 	checkSumSecondDeviation = 8
+	// byteSkip used to indicate when byte is required to be skipped in different ways.
+	byteSkip = 1
 )
 
 //nolint:gochecknoglobals
