@@ -1,23 +1,3 @@
-/*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-**/
-
-
 //{{NO_DEPENDENCIES}}
 // Microsoft Developer Studio generated include file.
 // Used by resource.rc
@@ -32,13 +12,13 @@
 #	define VER_FILEDESCRIPTION_STR	zabbix-agent2-plugin-ember-plus
 #endif
 #ifndef ZABBIX_VERSION_MAJOR
-#	define ZABBIX_VERSION_MAJOR		6
+#	define ZABBIX_VERSION_MAJOR		7
 #endif
 #ifndef ZABBIX_VERSION_MINOR
 #	define ZABBIX_VERSION_MINOR		0
 #endif
 #ifndef ZABBIX_VERSION_PATCH
-#	define ZABBIX_VERSION_PATCH 	44
+#	define ZABBIX_VERSION_PATCH 	0
 #endif
 #ifndef ZABBIX_VERSION_RC
 #	define ZABBIX_VERSION_RC		""
@@ -47,7 +27,7 @@
 #	define ZABBIX_VERSION_RC_NUM	1400
 #endif
 #ifndef ZABBIX_LICENSE_YEARS
-#	define ZABBIX_LICENSE_YEARS		"Zabbix"
+#	define ZABBIX_LICENSE_YEARS		"2001-2024"
 #endif
 
 #define VER_FILEVERSION		ZABBIX_VERSION_MAJOR,ZABBIX_VERSION_MINOR,ZABBIX_VERSION_PATCH,ZABBIX_VERSION_RC_NUM
